@@ -2,13 +2,19 @@
 
 use strict;
 
-my $LINTIAN_ROOT = $ARGV[0];
+BEGIN {
+  # determine LINTIAN_ROOT
+  my $LINTIAN_ROOT = $ENV{'LINTIAN_ROOT'} || '/usr/share/lintian';
+  $ENV{'LINTIAN_ROOT'} = $LINTIAN_ROOT
+    unless exists $ENV{'LINTIAN_ROOT'};
+}
 
-require "$LINTIAN_ROOT/lib/util.pl";
+use lib "$ENV{'LINTIAN_ROOT'}/lib";
+use Util;
 
 my $problems = 0;
 
-for my $f (<$LINTIAN_ROOT/checks/*.desc>) {
+for my $f (<$ENV{'LINTIAN_ROOT'}/checks/*.desc>) {
     my @sections = read_dpkg_control($f);
     for (my $i = 0; $i <= $#sections; $i++) {
 	if (exists $sections[$i]->{'tag'}) {
